@@ -257,12 +257,15 @@ defmodule Makeup.Lexers.ElixirLexer do
 
   sigils_interpol =
     for {ldelim, rdelim} <- sigil_delimiters do
-      sigil(ldelim, rdelim, [?a..?z], combinators_inside_string)
+      sigil(ldelim, rdelim, utf8_string([?a..?z], 1), combinators_inside_string)
     end
 
   sigils_no_interpol =
     for {ldelim, rdelim} <- sigil_delimiters do
-      sigil(ldelim, rdelim, [?A..?Z], [escape_delim(rdelim), iex_prompt_inside_string])
+      sigil(ldelim, rdelim, ascii_string([?A..?Z], min: 1), [
+        escape_delim(rdelim),
+        iex_prompt_inside_string
+      ])
     end
 
   all_sigils = sigils_interpol ++ sigils_no_interpol
@@ -511,14 +514,14 @@ defmodule Makeup.Lexers.ElixirLexer do
       |> List.wrap()
       |> List.to_string()
 
-    lexer = Map.get(get_sigil_lexers(), sigil)
+    {lexer, options} = Map.get(get_sigil_lexers(), sigil, {nil, []})
 
     if lexer do
       ["~", _sigil, separator | content_with_end_separator] = content
       end_separator = Enum.at(content_with_end_separator, -1)
       content = Enum.slice(content_with_end_separator, 0..-2//1) |> List.to_string()
 
-      inner_tokens = lexer.lex(content)
+      inner_tokens = lexer.lex(content, options)
 
       List.flatten([
         {:string_sigil, attrs, "~#{sigil}#{separator}"},
@@ -659,9 +662,9 @@ defmodule Makeup.Lexers.ElixirLexer do
       > Makeup.Lexers.ElixirLexer.register_sigil_lexer("H", Makeup.Lexers.HEExLexer)
 
   """
-  def register_sigil_lexer(sigil, lexer) do
+  def register_sigil_lexer(sigil, lexer, options \\ []) do
     lexers = get_sigil_lexers()
-    Application.put_env(:makeup_elixir, :sigil_lexers, Map.put(lexers, sigil, lexer))
+    Application.put_env(:makeup_elixir, :sigil_lexers, Map.put(lexers, sigil, {lexer, options}))
   end
 
   defp get_sigil_lexers() do
