@@ -493,7 +493,7 @@ defmodule ElixirLexerTokenizerTestSnippet do
     end
 
     test "sigils without interpolation (uppercase letter)" do
-      for b <- ?A..?Z do
+      for b <- ?A..?Z, b != ?H do
         for {llim, rlim} <- @sigil_delimiters, {llim, rlim} != {"{", "}"} do
           sigil = "~#{<<b>>}#{llim}x\#{y}z#{rlim}"
 
@@ -510,6 +510,10 @@ defmodule ElixirLexerTokenizerTestSnippet do
     assert lex("~U[2020-01-01 01:23:45Z]") == [{:literal_date, %{}, "~U[2020-01-01 01:23:45Z]"}]
   end
 
+  test "custom sigils" do
+    assert lex("~VEC[1 2.0 3]f64") == [{:string_sigil, %{}, "~VEC[1 2.0 3]f64"}]
+  end
+
   describe "strings and sigils" do
     test "unicode codepoints" do
       assert lex(~S["\u0000"]) == [
@@ -695,22 +699,4 @@ defmodule ElixirLexerTokenizerTestSnippet do
              {:punctuation, %{group_id: "group-1"}, "}"}
            ]
   end
-
-  describe "custom lexers for sigils" do
-    test "can register a custom lexer" do
-      defmodule MyCustomLexer do
-        def lex(input) do
-          [{:keyword, %{}, input}]
-        end
-      end
-
-      Makeup.Lexers.ElixirLexer.register_sigil_lexer("H", MyCustomLexer)
-
-      assert lex("~H|Hello, world!|") == [
-               {:string_sigil, %{}, "~H|"},
-               {:keyword, %{}, "Hello, world!"},
-               {:string_sigil, %{}, "|"}
-             ]
-    end
-  end
 end
